@@ -5,7 +5,7 @@
  *  UCRL-CODE-2002-008.
  *
  *  This file is part of PowerMan, a remote power management program.
- *  For details, see http://code.google.com/p/powerman/
+ *  For details, see http://github.com/chaos/powerman/
  *
  *  PowerMan is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
@@ -76,7 +76,7 @@ static char *prog;
 static char *hostname = NULL;
 static int auth_failure = 0;
 
-#define OPTIONS "p:h:A"
+#define OPTIONS "h:A"
 #if HAVE_GETOPT_LONG
 #define GETOPT(ac,av,opt,lopt) getopt_long(ac,av,opt,lopt,NULL)
 static const struct option longopts[] = {
